FastIcons class

This class is used to access the icons of the font package.

Example:

Icon(FastIcons.awesome5.addressBook)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

ant → AntDesign
final
awesome → FontAwesome
final
awesome5 → FontAwesome5
final
awesomeBrand5 → FontAwesome5Brands
final
awesomeSolid5 → FontAwesome5Solid
final
bradico → Brandico
final
elico → Fontelico
final
elusive → Elusive
final
entypo → Entypo
final
evil → EvilIcons
final
feather → Feather
final
foundation → Foundation
final
ionicIcons → Ionicons
final
line → Linecons
final
linear → AntDesign
final
maki → Maki
final
material → MaterialIcons
final
mci → MaterialCommunityIcons
final
metocos → Meteocons
final
mfgLabs → MfgLabs
final
modernPictograms → ModernPictograms
final
ocIcons → Octicons
final
rpgAwesome → RpgAwesome
final
simpleLine → SimpleLineIcons
final
typIcons → Typicons
final
weather → WeatherIcons
final
web → WebSymbols
final
zocial → Zocial
final