FastAudioService class

Properties

audio → AudioPlayer?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

duration(AudioPlayer player) → Future<Duration?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause(AudioPlayer player) → Future<void>
pauseResume(AudioPlayer player) → Future<void>
play(AudioPlayer player) → Future<void>
position(AudioPlayer player) → Future<Duration?>
resume(AudioPlayer player) → Future<void>
seek(AudioPlayer player, Duration position) → Future<void>
stop(AudioPlayer player) → Future<void>
toString() → String
A string representation of this object.
inherited
velocity(AudioPlayer player, double v) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

i → FastAudioService
no setter

Static Methods

getSource(String url, {bool isFile = false}) → Source