services/picker library
Classes
- FastPickerService
- use this service to pick files from device
- FileData
- use this class to get file data path is the file path
- FilePicker
- FilePickerLinux
- FilePickerMacOS
- FilePickerResult
- FilePickerWindows
- PlatformFile
Enums
- FastPickerType
- use this enum to select the type of file any any file media any media file image only image file video only video file audio only audio file custom custom file type
- FilePickerStatus
- Status of the file picker.
- FileType
- Type of file to pick.