FastTheme class

use this extension to get application theme

example:

  class MyApp extends StatelessWidget {
  MyApp({super.key});

  final theme = FastTheme(seed: Colors.green);

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      darkTheme: theme.dark,
      theme: theme.light,
      home: const HomePage(),
    );
  }
}

Constructors

FastTheme({required Color seed, String? font})

Properties

dark → ThemeData
no setter
font → String?
final
hashCode → int
The hash code for this object.
no setterinherited
light → ThemeData
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seed → Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited