FastAnimate class

use this widget to animate your widgets

example:

FastAnimate(
  type: FastAnimateType.fadeInDownBig,
  duration: const Duration(seconds: 1),
  child: Text('Text H1', style: context.H1),
),
Inheritance

Constructors

FastAnimate({Key? key, required FastAnimateType type, required Widget child, Duration delay = const Duration(milliseconds: 0), Duration duration = const Duration(milliseconds: 200), bool infinite = false, bool animate = true, Curve curve = Curves.easeInOut, void onFinish(AnimateDoDirection)?, void controller(AnimationController)?, bool manualTrigger = false})
use this widget to animate your widgets
const

Properties

animate → bool
final
child → Widget
final
controller → void Function(AnimationController)?
final
curve → Curve
final
delay → Duration
final
duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
infinite → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
manualTrigger → bool
final
onFinish → void Function(AnimateDoDirection)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → FastAnimateType
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited