FastCalendar class

use this widget to get a calendar

example:

 FastCalendar(),
Inheritance

Constructors

FastCalendar({Key? key, DateTime? firstDate, DateTime? lastDate, DateTime? initialFocusDate, bool rangeMode = false, double maxHeight = 400, double maxWidth = 400, String? locale, BoxDecoration? decoration, DateTime? initialSelectedFirstDate, DateTime? initialSelectedLastDate, void onRangeSelected(DateTime?, DateTime?)?})
use this widget to get a calendar
const

Properties

decoration → BoxDecoration?
final
firstDate → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
initialFocusDate → DateTime?
final
initialSelectedFirstDate → DateTime?
final
initialSelectedLastDate → DateTime?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lastDate → DateTime?
final
locale → String?
final
maxHeight → double
final
maxWidth → double
final
onRangeSelected → void Function(DateTime?, DateTime?)?
final
rangeMode → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FastCalendar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited