FastCarousel class

A fast carousel widget that displays a horizontally scrollable list of items.

Inheritance

Constructors

FastCarousel({Key? key, required Widget itemBuilder(BuildContext, int)?, required int itemCount, List<String>? labels, double? height, double scale = 0.9, Duration duration = const Duration(seconds: 10), double fraction = 0.8})
Creates a new instance of FastCarousel.
const

Properties

duration → Duration
The duration between automatic item transitions.
final
fraction → double
The fraction of the viewport occupied by each item.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
The height of the carousel.
final
itemBuilder → Widget Function(BuildContext, int)?
The builder function for each item in the carousel.
final
itemCount → int
The number of items in the carousel.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labels → List<String>?
The list of labels to display on top of each item.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
The scaling factor for each item in the carousel.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited