FastFormField class

Inheritance

Constructors

FastFormField({Key? key, String? label, void onChanged(String)?, bool? autoFocus, String? hint, Widget? prefix, Widget? suffix, bool? isPassword, TextEditingController? controller, String? validator(String?)?, void onFieldSubmitted(String)?, TextInputType? textInputType, TextInputAction? textInputAction, List<TextInputFormatter>? mask, dynamic onEditingComplete()?, double radius = 8, int maxLines = 1, int minLines = 1})
FastFormField
const

Properties

autoFocus → bool?
final
controller → TextEditingController?
final
hashCode → int
The hash code for this object.
no setterinherited
hint → String?
final
isPassword → bool?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String?
final
mask → List<TextInputFormatter>?
final
maxLines → int
final
minLines → int
final
onChanged → void Function(String)?
final
onEditingComplete → dynamic Function()?
final
onFieldSubmitted → void Function(String)?
final
prefix → Widget?
final
radius → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffix → Widget?
final
textInputAction → TextInputAction?
final
textInputType → TextInputType?
final
validator → String? Function(String?)?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited