FastSearchSelect<T> class

Inheritance

Constructors

FastSearchSelect({Key? key, bool showClearButton = true, String searchTitle = 'Search', Future<List<T>> onSearch(String)?, String? hint, List<T>? initialValue, bool alowMultiple = true, double radius = 8, void onChanged(List<T>?)?, int? max, String? validation(List<T>)?, Widget itemBuilder(T)?, required List<T> items})
const

Properties

alowMultiple → bool
final
hashCode → int
The hash code for this object.
no setterinherited
hint → String?
final
initialValue → List<T>?
final
itemBuilder → Widget Function(T)?
final
items → List<T>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
max → int?
final
onChanged → void Function(List<T>?)?
final
onSearch → Future<List<T>> Function(String)?
final
radius → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchTitle → String
final
showClearButton → bool
final
validation → String? Function(List<T>)?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FastSearchSelect<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited